@@ -62,9 +62,9 @@ gsf_doc_meta_data_class_init (GObjectClass *gobject_class)
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_CLASS (GsfDocMetaData, gsf_doc_meta_data,
-	   gsf_doc_meta_data_class_init, gsf_doc_meta_data_init,
-	   G_TYPE_OBJECT)
+GSF_DYNAMIC_CLASS(GsfDocMetaData, gsf_doc_meta_data,
+		  gsf_doc_meta_data_class_init, gsf_doc_meta_data_init,
+		  G_TYPE_OBJECT)
 
 /**********************************************************************/
 
@@ -249,14 +249,13 @@ gsf_doc_prop_new  (char *name)
  * gsf_doc_prop_free :
  * @prop : #GsfDocProp
  *
- * If @prop is non NULL free the memory assosociated with it
+ * If @prop is non NULL free the memory associated with it
  **/
 void
 gsf_doc_prop_free (GsfDocProp *prop)
 {
 	if (NULL != prop) {
-		if (prop->linked_to)
-			g_free (prop->linked_to);
+		g_free (prop->linked_to);
 
 		if (prop->val) {
 			g_value_unset (prop->val);
