@@ -2,8 +2,8 @@
 /*
  * gsf-input-gzip.c: wrapper to uncompress gzipped input
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
- * Copyright (C) 2005 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2005-2006 Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -50,7 +50,7 @@ struct _GsfInputGZip {
 	guint8   *buf;
 	size_t    buf_size;
 
-	size_t    header_size, trailer_size;
+	gsf_off_t header_size, trailer_size;
 	gsf_off_t seek_skipped;
 };
 
@@ -211,6 +211,9 @@ gsf_input_gzip_new (GsfInput *source, GError **err)
 		return NULL;
 	}
 
+	if (gzip)
+		gsf_input_set_name (GSF_INPUT (gzip), gsf_input_name (source));
+
 	return GSF_INPUT (gzip);
 }
 
@@ -348,9 +351,7 @@ gsf_input_gzip_seek (GsfInput *input, gsf_off_t offset, GSeekType whence)
 	}
 
 	if (pos < input->cur_offset) {
-		if (gsf_input_seek (gzip->source,
-				    (gsf_off_t)gzip->header_size,
-				    G_SEEK_SET))
+		if (gsf_input_seek (gzip->source, gzip->header_size, G_SEEK_SET))
 			return TRUE;
 		gzip->crc = crc32 (0L, Z_NULL, 0);
 		gzip->stream.avail_in = 0;
@@ -529,5 +530,7 @@ gsf_input_gzip_class_init (GObjectClass *gobject_class)
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_CLASS (GsfInputGZip, gsf_input_gzip,
-	   gsf_input_gzip_class_init, gsf_input_gzip_init, GSF_INPUT_TYPE)
+GSF_DYNAMIC_CLASS (GsfInputGZip, gsf_input_gzip,
+		   gsf_input_gzip_class_init, gsf_input_gzip_init,
+		   GSF_INPUT_TYPE)
+
