@@ -2,7 +2,7 @@
 /*
  * gsf-input-textline.c: textline based input
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -66,7 +66,8 @@ gsf_input_textline_new (GsfInput *source)
 	input->source = source;
 	input->buf  = NULL;
 	input->buf_size = 0;
-	gsf_input_set_size (GSF_INPUT (source), gsf_input_size (source));
+	gsf_input_set_size (GSF_INPUT (input), gsf_input_size (source));
+	gsf_input_set_name (GSF_INPUT (input), gsf_input_name (source));
 
 	return GSF_INPUT (input);
 }
@@ -80,10 +81,8 @@ gsf_input_textline_finalize (GObject *obj)
 		g_object_unref (G_OBJECT (input->source));
 		input->source = NULL;
 	}
-	if (input->buf != NULL) {
-		g_free (input->buf);
-		input->buf  = NULL;
-	}
+	g_free (input->buf);
+	input->buf  = NULL;
 	input->buf_size = 0;
 
 	parent_class->finalize (obj);
@@ -144,18 +143,19 @@ gsf_input_textline_class_init (GObjectClass *gobject_class)
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_CLASS (GsfInputTextline, gsf_input_textline,
-	   gsf_input_textline_class_init, gsf_input_textline_init, GSF_INPUT_TYPE)
+GSF_DYNAMIC_CLASS (GsfInputTextline, gsf_input_textline,
+		   gsf_input_textline_class_init, gsf_input_textline_init,
+		   GSF_INPUT_TYPE)
 
 /**
  * gsf_input_textline_ascii_gets :
- * @input :
+ * @textline : #GsfInputTextline
  *
  * A utility routine to read things line by line from the underlying source.
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * returns the string read, or NULL on eof.
+ * Returns : the string read, or NULL on eof.
  **/
 unsigned char *
 gsf_input_textline_ascii_gets (GsfInputTextline *textline)
@@ -236,13 +236,13 @@ gsf_input_textline_ascii_gets (GsfInputTextline *textline)
 
 /**
  * gsf_input_textline_utf8_gets :
- * @input :
+ * @textline : #GsfInputTextline
  *
  * A utility routine to read things line by line from the underlying source.
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * returns the string read, or NULL on eof.
+ * Returns: the string read, or NULL on eof.
  **/
 guint8 *
 gsf_input_textline_utf8_gets (GsfInputTextline *textline)
