@@ -2,7 +2,7 @@
 /*
  * gsf-input-textline.h: a utility wrapper to pull in text, line by line.
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -22,7 +22,7 @@
 #ifndef GSF_INPUT_TEXTLINE_H
 #define GSF_INPUT_TEXTLINE_H
 
-#include "gsf-input.h"
+#include <gsf/gsf-input.h>
 
 G_BEGIN_DECLS
 
@@ -32,7 +32,9 @@ G_BEGIN_DECLS
 
 typedef struct _GsfInputTextline GsfInputTextline;
 
-GType gsf_input_textline_get_type (void);
+GType gsf_input_textline_get_type      (void) G_GNUC_CONST;
+void  gsf_input_textline_register_type (GTypeModule *module);
+
 
 GsfInput      *gsf_input_textline_new		(GsfInput *source);
 unsigned char *gsf_input_textline_ascii_gets	(GsfInputTextline *textline);
