@@ -204,6 +204,17 @@ gsf_xml_gvalue_from_str (GValue *res, GType t, char const *str)
 	g_return_val_if_fail (str != NULL, FALSE);
 
 	g_value_init (res, t);
+
+	/* If the passed-in type is derived from G_TYPE_ENUM
+	 * or G_TYPE_FLAGS, we cannot switch on its type
+	 * because we don't know its GType at compile time.
+	 * We just pretend to have a G_TYPE_ENUM/G_TYPE_FLAGS.
+	 */
+	if (G_TYPE_FUNDAMENTAL (t) == G_TYPE_ENUM ||
+	    G_TYPE_FUNDAMENTAL (t) == G_TYPE_FLAGS) {
+		t = G_TYPE_FUNDAMENTAL (t);
+	}
+
 	switch (t) {
 	case G_TYPE_CHAR:
 		g_value_set_char (res, str[0]);
@@ -230,10 +241,10 @@ gsf_xml_gvalue_from_str (GValue *res, GType t, char const *str)
 		g_value_set_ulong (res, strtoul (str, NULL, 0));
 		break; 
 	case G_TYPE_ENUM:
-		g_value_set_enum (res, glade_enum_from_string (t, str));
+		g_value_set_enum (res, glade_enum_from_string (G_VALUE_TYPE (res), str));
 		break;
 	case G_TYPE_FLAGS:
-		g_value_set_flags (res, glade_flags_from_string (t, str));
+		g_value_set_flags (res, glade_flags_from_string (G_VALUE_TYPE (res), str));
 		break;
 	case G_TYPE_FLOAT:
 		g_value_set_float (res, g_strtod (str, NULL));
@@ -252,7 +263,7 @@ gsf_xml_gvalue_from_str (GValue *res, GType t, char const *str)
 				gsf_value_set_timestamp (res, &ts);
 				break;
 			}
-		}
+		} else g_warning ("gsf_xml_gvalue_from_str(): Don't know how to handle type '%s'", g_type_name (t));
 
 		return FALSE;
 	}
@@ -419,6 +430,7 @@ typedef struct {
 	GSList	 	 *ns_stack;
 	GHashTable	 *ns_prefixes;
 	GPtrArray	 *ns_by_id;
+	GSList	 	 *contents_stack;
 	gboolean          initialized;
 	gint	  	  unknown_depth; /* handle recursive unknown tags */
 	gboolean	  from_unknown_handler;
@@ -451,9 +463,15 @@ static void
 push_child (GsfXMLInInternal *state, GsfXMLInNode const *node, int default_ns_id,
 	    xmlChar const **attrs, GsfXMLInExtension *ext)
 {
-	if (node->has_content == GSF_XML_CONTENT &&
-	    state->pub.content->len > 0) {
-		g_warning ("too lazy to support nested unshared content for now.  We'll add it for 2.0");
+	if (node->has_content == GSF_XML_CONTENT) {
+		if (state->pub.content->len) {
+			state->contents_stack =	g_slist_prepend
+				(state->contents_stack, state->pub.content);
+			state->pub.content = g_string_sized_new (128);
+		} else {
+			state->contents_stack = g_slist_prepend
+				(state->contents_stack, NULL);
+		}
 	}
 	state->pub.node_stack	= g_slist_prepend (state->pub.node_stack,
 		(gpointer)state->pub.node);
@@ -657,8 +675,22 @@ gsf_xml_in_end_element (GsfXMLInInternal *state,
 	node = (GsfXMLInNodeInternal *) state->pub.node;
 	if (node->pub.end)
 		node->pub.end (&state->pub, NULL);
-	if (node->pub.has_content == GSF_XML_CONTENT)
-		g_string_truncate (state->pub.content, 0);
+
+	if (node->pub.has_content == GSF_XML_CONTENT) {
+		GString *top;
+
+		g_return_if_fail (state->contents_stack != NULL);
+		top = state->contents_stack->data;
+		state->contents_stack = g_slist_remove
+			(state->contents_stack, top);
+
+		if (top) {
+			g_string_free (state->pub.content, TRUE);
+			state->pub.content = top;
+		} else {
+			g_string_truncate (state->pub.content, 0);
+		}
+	}
 
 	/* Free any potential extensions associated with the current node */
 	for (ptr = node->extensions; ptr != NULL ; ptr = ptr->next)
@@ -726,6 +758,7 @@ gsf_xml_in_start_document (GsfXMLInInternal *state)
 	state->ns_prefixes	= g_hash_table_new_full (
 		g_str_hash, g_str_equal,
 		g_free, (GDestroyNotify) gsf_free_xmlinnsinstance);
+	state->contents_stack	= NULL;
 	state->from_unknown_handler = FALSE;
 }
 
@@ -1200,9 +1233,9 @@ gsf_xml_out_class_init (GObjectClass *gobject_class)
 			TRUE, GSF_PARAM_STATIC | G_PARAM_READWRITE));
 }
 
-GSF_CLASS (GsfXMLOut, gsf_xml_out,
-	   gsf_xml_out_class_init, gsf_xml_out_init,
-	   G_TYPE_OBJECT)
+GSF_DYNAMIC_CLASS (GsfXMLOut, gsf_xml_out,
+		   gsf_xml_out_class_init, gsf_xml_out_init,
+		   G_TYPE_OBJECT)
 
 /**
  * gsf_xml_out_new :
@@ -1638,6 +1671,7 @@ gsf_xml_out_add_gvalue (GsfXMLOut *xml, char const *id, GValue const *val)
 	case G_TYPE_CHAR: {
 		char c[2] = { 0, 0 };
 		c[0] = g_value_get_char (val);
+		/* FIXME: What if we are in 0x80-0xff? */
 		gsf_xml_out_add_cstr (xml, id, c);
 		break;
 	}
@@ -1645,6 +1679,7 @@ gsf_xml_out_add_gvalue (GsfXMLOut *xml, char const *id, GValue const *val)
 	case G_TYPE_UCHAR: {
 		unsigned char c[2] = { 0, 0 };
 		c[0] = g_value_get_uchar (val);
+		/* FIXME: What if we are in 0x80-0xff? */
 		gsf_xml_out_add_cstr (xml, id, c);
 		break;
 	}
@@ -1685,9 +1720,10 @@ gsf_xml_out_add_gvalue (GsfXMLOut *xml, char const *id, GValue const *val)
 
 	default:
 		if (GSF_TIMESTAMP_TYPE == t) {
-			char *str = gsf_timestamp_as_string (
-				(GsfTimestamp const *)g_value_get_boxed (val));
+			GsfTimestamp const *ts = g_value_get_boxed (val);
+			char *str = gsf_timestamp_as_string (ts);
 			gsf_xml_out_add_cstr (xml, id, str);
+			g_free (str);
 			break;
 		}
 	}
