@@ -2,7 +2,7 @@
 /*
  * gsf-output-memory.c:
  *
- * Copyright (C) 2002-2004 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2006 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -151,7 +151,7 @@ gsf_output_memory_vprintf (GsfOutput *output, char const *format, va_list args)
 				     mem->capacity - output->cur_offset,
 				     format, args);
 
-		if (len < mem->capacity - output->cur_offset)
+		if (len < (gsf_off_t)(mem->capacity - output->cur_offset))
 			return len; /* There was sufficient space */
 
 		return parent_class->Vprintf (output, format, args2);
@@ -195,6 +195,7 @@ gsf_output_memory_get_bytes (GsfOutputMemory * mem)
 	return mem->buffer;
 }
 
-GSF_CLASS (GsfOutputMemory, gsf_output_memory,
-           gsf_output_memory_class_init, gsf_output_memory_init, GSF_OUTPUT_TYPE)
+GSF_DYNAMIC_CLASS (GsfOutputMemory, gsf_output_memory,
+		   gsf_output_memory_class_init, gsf_output_memory_init,
+		   GSF_OUTPUT_TYPE)
 
